@@ -208,8 +208,12 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
 
         { MENU_BROWSER,                NULL,                   _("_Browser"),                      NULL,                NULL,                               NULL },
         { AM_LOAD_HOME_DIR,            GTK_STOCK_HOME,         _("Go to _Home Directory"),         "<Alt>Home",         _("Go to Home Directory"),          G_CALLBACK(Browser_Load_Home_Directory) },
-        { AM_LOAD_DEFAULT_DIR,         GTK_STOCK_HARDDISK,     _("Go to _Default Directory"),      "<Control>D",        _("Go to Default Directory"),       G_CALLBACK(Browser_Load_Default_Directory) },
-        { AM_SET_PATH_AS_DEFAULT,      GTK_STOCK_JUMP_TO,      _("Set _Current Path as Default"),  NULL,                _("Set Current Path as Default"),   G_CALLBACK(Set_Current_Path_As_Default) },
+        { AM_LOAD_DESKTOP_DIR,         GTK_STOCK_JUMP_TO,      _("Go to Desktop Directory"),       NULL,         		_("Go to Desktop Directory"),       G_CALLBACK(Browser_Load_Desktop_Directory) },
+        { AM_LOAD_DOCUMENTS_DIR,       GTK_STOCK_JUMP_TO,      _("Go to Documents Directory"),     NULL,         		_("Go to Documents Directory"),     G_CALLBACK(Browser_Load_Documents_Directory) },
+        { AM_LOAD_DOWNLOADS_DIR,       GTK_STOCK_JUMP_TO,      _("Go to Downloads Directory"),     NULL,         		_("Go to Downloads Directory"),     G_CALLBACK(Browser_Load_Downloads_Directory) },
+        { AM_LOAD_MUSIC_DIR,           GTK_STOCK_JUMP_TO,      _("Go to Music Directory"),         NULL,         		_("Go to Music Directory"),         G_CALLBACK(Browser_Load_Music_Directory) },
+        { AM_LOAD_DEFAULT_DIR,         GTK_STOCK_JUMP_TO,      _("Go to _Default Directory"),      "<Control>D",        _("Go to Default Directory"),       G_CALLBACK(Browser_Load_Default_Directory) },
+        { AM_SET_PATH_AS_DEFAULT,      GTK_STOCK_DIRECTORY,    _("Set _Current Path as Default"),  NULL,                _("Set Current Path as Default"),   G_CALLBACK(Set_Current_Path_As_Default) },
         { AM_TREE_OR_ARTISTALBUM_VIEW, "easytag-artist-album", _("Tree View | Artist-Album View"), NULL,                _("Tree View | Artist-Album View"), G_CALLBACK(Menu_Sort_Action) },
         { AM_RENAME_DIR,               GTK_STOCK_INDEX,        _("Rename Directory ..."),          "F2",                _("Rename Directory ..."),          G_CALLBACK(Browser_Open_Rename_Directory_Window) },
         { AM_RELOAD_DIRECTORY,         GTK_STOCK_REFRESH,      _("Reload Directory"),              "F5",                _("Reload Directory"),              G_CALLBACK(Browser_Reload_Directory) },
@@ -233,7 +237,7 @@ void Create_UI (GtkWidget **ppmenubar, GtkWidget **pptoolbar)
         { AM_OPEN_OPTIONS_WINDOW,   GTK_STOCK_PREFERENCES,  _("_Preferences ..."),                  "<Alt>P",     _("Preferences ..."),                 G_CALLBACK(Open_OptionsWindow) },
 
         { MENU_HELP,                NULL,                   _("_Help"),                             NULL,         NULL,                                 NULL },
-        { AM_OPEN_ABOUT_WINDOW,     GTK_STOCK_HELP,         _("_About"),                            NULL,         _("About"),                           G_CALLBACK(Show_About_Window) },
+        { AM_OPEN_ABOUT_WINDOW,     GTK_STOCK_ABOUT,        _("_About"),                            NULL,         _("About"),                           G_CALLBACK(Show_About_Window) },
 
 
         /*
@@ -441,11 +445,12 @@ void Statusbar_Message (gchar *message, gint with_timer)
     if (!StatusBar) return;
 
     /* Validate UTF8 */
-    if (!g_utf8_validate(message, -1, NULL))
+    /*if (!g_utf8_validate(message, -1, NULL))
         msg_temp = convert_to_utf8(message);
     else
-        msg_temp = g_strdup(message);
-
+        msg_temp = g_strdup(message);*/
+    msg_temp = Try_To_Validate_Utf8_String(message);
+    
     /* Remove a running timer */
     Statusbar_Remove_Timer();
 
