@@ -50,6 +50,7 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define POPUP_DIR               "DirPopup"
 #define POPUP_SUBMENU_SCANNER   "ScannerSubpopup"
 #define POPUP_DIR_RUN_AUDIO     "DirPopupRunAudio"
+#define POPUP_LOG               "LogPopup"
 
 #define AM_PREV                     "PreviousFile"
 #define AM_NEXT                     "NextFile"
@@ -68,6 +69,10 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define AM_INVERT_SELECTION         "SelInv"
 #define AM_DELETE_FILE              "DeleteFile"
 #define AM_LOAD_HOME_DIR            "GoToHome"
+#define AM_LOAD_DESKTOP_DIR         "GoToDesktop"
+#define AM_LOAD_DOCUMENTS_DIR       "GoToDocument"
+#define AM_LOAD_DOWNLOADS_DIR       "GoToDownload"
+#define AM_LOAD_MUSIC_DIR           "GoToMusic"
 #define AM_LOAD_DEFAULT_DIR         "GoToDefaultPath"
 #define AM_SET_PATH_AS_DEFAULT      "SetDefaultPath"
 #define AM_RENAME_DIR               "RenameDir"
@@ -97,6 +102,8 @@ GtkWidget *CheckMenuItemBrowseHiddenDirMainMenu;
 #define AM_ALBUM_RUN_AUDIO_PLAYER   "AlbumRunAudio"
 #define AM_ALBUM_OPEN_FILE_WITH     "AlbumOpenFile"
 
+#define AM_LOG_CLEAN                "CleanLog"
+
 #define AM_STOP                     "Stop"
 #define AM_VIEWMODE_TOGGLE          "ViewModeToggle"
 
