@@ -28,8 +28,8 @@
 #ifndef _ID3LIB_BUGFIX_H_
 #define _ID3LIB_BUGFIX_H_
 
-#ifdef ENABLE_MP3
 
+#ifdef ENABLE_ID3LIB
 
 #include "id3.h"
 
@@ -51,6 +51,6 @@ extern "C"
 #endif /*__cplusplus*/
 
 
-#endif /* ENABLE_MP3 */
+#endif /* ENABLE_ID3LIB */
 
 #endif /* _ID3LIB_BUGFIX_H_ */
